@@ -564,6 +564,12 @@ html_destroy_cb (GtkObject *object,
 	cd->html = NULL;
 } */
 
+static void
+indentation_changed (GtkWidget *w, guint level, GtkHTMLControlData *cd)
+{
+	gtk_widget_set_sensitive (cd->unindent_button, level != 0);
+}
+
 static GtkWidget *
 create_style_toolbar (GtkHTMLControlData *cd)
 {
@@ -610,6 +616,9 @@ create_style_toolbar (GtkHTMLControlData *cd)
 	cd->right_align_button = editor_toolbar_alignment_group[2].widget;
 
 	cd->unindent_button  = editor_toolbar_style_uiinfo [8].widget;
+	gtk_signal_connect (GTK_OBJECT (cd->html), "current_paragraph_indentation_changed",
+			    indentation_changed, cd);
+
 	cd->indent_button    = editor_toolbar_style_uiinfo [9].widget;
 
 	/* gtk_signal_connect (GTK_OBJECT (cd->html), "destroy",
@@ -630,10 +639,10 @@ toolbar_item_update_sensitivity (GtkWidget *widget, gpointer data)
 	GtkHTMLControlData *cd = (GtkHTMLControlData *)data;
 	gboolean sensitive;
 
-	sensitive = (cd->format_html
+	sensitive = ((cd->format_html && widget != cd->unindent_button)
 		     || widget == cd->paragraph_option
 		     || widget == cd->indent_button
-		     || widget == cd->unindent_button
+		     || (widget == cd->unindent_button && gtk_html_get_paragraph_indentation (cd->html))
 		     || widget == cd->left_align_button
 		     || widget == cd->center_button
 		     || widget == cd->right_align_button);
