@@ -53,7 +53,7 @@ void  html_engine_append_object           (HTMLEngine  *e,
 void  html_engine_append_flow             (HTMLEngine  *e,
 					   HTMLObject  *o,
 					   guint        len);
-void  html_engine_insert_link             (HTMLEngine  *e,
+void  html_engine_edit_set_link           (HTMLEngine  *e,
 					   const gchar *url,
 					   const gchar *target);
 void  html_engine_insert_empty_paragraph  (HTMLEngine  *e);
