@@ -114,14 +114,19 @@ font_name_substitute_attr (const gchar *name, gint nth, gchar *val)
 	const gchar *s;
 	gchar *s1, *s2, *rv;
 
+	if (!name)
+		return NULL;
+
 	for (s = name; nth; nth--) {
 		s = strchr (s, '-');
-		g_assert (s);
+		if (!s)
+			return NULL;
 		s ++;
 	}
-	s1 = g_strndup (name, s - name);
 	s2 = strchr (s, '-');
-	g_assert (s);
+	if (!s2)
+		return NULL;
+	s1 = g_strndup (name, s - name);
 
 	rv = g_strconcat (s1, val, s2, NULL);
 	g_free (s1);
@@ -236,7 +241,7 @@ find_font_with_similar_size (gchar **list, gint n, gint size, gboolean points, g
 	if (n) {
 		gint i, small, large, as, small_idx, large_idx;
 
-		small = large = 0;
+		small = large = small_idx = large_idx = 0;
 		for (i = 0; i < n; i++) {
 			as = get_size (list [i], points);
 
@@ -289,12 +294,12 @@ load_font_with_name (gchar *name)
 	return font;
 }
 
-static gpointer
-e_font_from_face (gchar *face, gint size, gboolean points, gchar *weight, gchar *slant,
-		  gboolean known_size, gboolean smaller)
+static gchar *
+e_font_lookup_face (gchar *face, gint size, gboolean points, gchar *weight, gchar *slant,
+		    gboolean known_size, gboolean smaller)
 {
 	gchar *f1, *f2, *f3, *f4, **list, **filtered = NULL;
-	gpointer font = NULL;
+	gchar *font_name = NULL;
 	gint n;
 
 	/* clear weight, slant and size */
@@ -306,6 +311,11 @@ e_font_from_face (gchar *face, gint size, gboolean points, gchar *weight, gchar
 	f4 = font_name_substitute_attr (f3, 4, "*");
 	g_free (f3);
 
+	if (!f4) {
+		g_warning ("Don't know how to use face: %s", face ? face : "NULL");
+		return NULL;
+	}
+
 	list = lookup_fonts (f4, &n);
 	g_free (f4);
 
@@ -317,28 +327,75 @@ e_font_from_face (gchar *face, gint size, gboolean points, gchar *weight, gchar
 		gchar *name;
 		if (known_size) {
 
+
 			name = find_font_with_similar_size (filtered, n, size, points, smaller);
+			
 			if (name)
-				font = load_font_with_name (name);
+				font_name = g_strdup (name);
 		} else {
 			gchar *s;
 
 			f1 = font_name_substitute_attr (face, 3, weight);
 			f2 = font_name_substitute_attr (f1,   4, slant);
+			if (!f2) {
+				g_warning ("Don't know how to use face: %s", face ? face : "NULL");
+				return NULL;
+			}
 			s    = g_strdup_printf ("%d", size);
 			name = font_name_substitute_attr (f2, points ? 8 : 7, s);
+			if (!name) {
+				g_warning ("Don't know how to use face: %s", face ? face : "NULL");
+				return NULL;
+			}
 			g_free (f1);
 			g_free (f2);
 			g_free (s);
 
-			font = load_font_with_name (name);
-			g_free (name);
+			font_name = name;
 		}
 
 	}
 	if (filtered != list)
 		g_free (filtered);
 
+	return font_name;
+}
+
+static gpointer
+e_font_from_face (gchar *face, gint size, gboolean points, gchar *weight, gchar *slant,
+		  gboolean known_size, gboolean smaller)
+{
+	gchar *better_name;
+	gchar **fontnames;
+	GString *newface;
+	gint i;
+	gpointer font = NULL;
+	gboolean found = FALSE;
+
+	newface = g_string_new ("");
+	fontnames = g_strsplit (face, ",", 50);
+	for (i = 0; fontnames && fontnames[i] != NULL; i++) {
+		char *name = g_strstrip (fontnames[i]);
+
+		better_name = e_font_lookup_face (name, size, points, weight, slant, known_size, smaller);
+		
+		if (i)
+			g_string_append (newface, ",");
+		
+		if (better_name) {
+			g_string_append (newface, better_name);
+			g_free (better_name);
+			found = TRUE;
+		} else {
+			g_string_append (newface, name);
+		}
+	}
+	g_strfreev (fontnames);
+	
+	if (found)
+		font = load_font_with_name (newface->str);
+	g_string_free (newface, TRUE);
+	
 	return font;
 }
 
@@ -486,7 +543,9 @@ begin (HTMLPainter *painter, int x1, int y1, int x2, int y2)
 	/* printf ("painter begin %d,%d %d,%d\n", x1, y1, x2, y2); */
 
 	gdk_painter = HTML_GDK_PAINTER (painter);
+	g_return_if_fail (gdk_painter->window != NULL);
 	visual = gdk_window_get_visual (gdk_painter->window);
+	g_return_if_fail (visual != NULL);
 
 	if (gdk_painter->double_buffer){
 		const int width = x2 - x1 + 1;
